import java.util.*;

public class CollectionADTTester extends Tester {
	
	public static void main(String[] args)
	{
		new CollectionADTTester().runTests();
	}
	
	//GLOBALS
	private final Integer START = new Integer(0);
	private final Integer STOP  = new Integer(10000);
	
	//STACK
	private MyStack<Integer> getStack(int start, int stop)
	{
		MyStack<Integer> stack = new MyStack<Integer>();
		for (int i = start; i < stop; i++)
			stack.push(i);
		return stack;
	}
	
	private MyStack<Integer> getDefaultStack()
	{
		return getStack(START, STOP);
	}
	
	public void testMyStack() throws Exception
	{
		MyStackInterface<Integer> stack = getDefaultStack();
		
		assert(!stack.isEmpty());
		assert(new MyStack().isEmpty());
		for (int i = STOP-1; i >= START; i--)
			assert(stack.pop().equals(i));
		assert(stack.isEmpty());
	}
	
	public void testMyStackException() throws MyEmptyCollectionException
	{
		expectException(new MyEmptyCollectionException());
		new MyStack().pop();
	}
	
	//SET
	
	private MySet<Integer> makeSet(int start, int stop)
	{
		MySet<Integer> set = new MySet<Integer>();
		for (int i = start; i < stop; i++)
			set.add(i);
		return set;
	}
	
	private MySet<Integer> getDefaultSet()
	{ return makeSet(START, STOP); }
	
	public void testMySetInterface()
	{
		MySet<Integer> set = getDefaultSet();
		assert(!set.add(START));
		assert(set.add(STOP));
		set.clear();
		assert(set.add(START));
	
		set = getDefaultSet();
		assert(set.contains(START + (STOP-START)/2));
		Set<Integer> checkSet = new TreeSet<Integer>();
		for (Integer i : set)
			checkSet.add(i);
		
		assert(checkSet.size() == STOP-START);
	}
	
	//MAP
	private MyMap<Integer, Integer> makeMap(int start, int stop)
	{
		MyMap<Integer, Integer> map = new MyMap<Integer, Integer>();
		for (int i = start; i < stop; i++)
			map.put(i, i);
		return map;
	}
	private MyMap<Integer, Integer> getDefaultMap()
	{ return makeMap(START, STOP); }
	
	public void testMyMapInterface()
	{
		MyMap<Integer, Integer> map = getDefaultMap();
		
		for (int i = START; i < STOP; i++)
			assert(map.get(i).equals(i));
		
		assert(map.put((STOP - START)/2, (STOP - START)/2).equals((STOP - START)/2));
	}
	
	
}


