import java.util.*;


public class MyCollectionsTester extends Tester{
	
	public static void main(String[] args)
	{
		new MyCollectionsTester().runTests();
	}
	
	private final int 		START_INDEX = 0;
	private final int 		STOP_INDEX  = 1000;
	private final Integer   HALF_INDEX 	= STOP_INDEX/2;
	private final Integer 	FIVE 		= new Integer(5);
	
	private List<Integer> makeList(int start, int stop)
	{
		List<Integer> list = new ArrayList<Integer>();
		for (int i = start; i < stop; i++)
			list.add(i);
		return list;
	}
	
	private List<Integer> getDefaultList()
	{
		return makeList(START_INDEX, STOP_INDEX);
	}
	
	private List<Integer> getDefault2ndList()
	{
		return makeList(STOP_INDEX, (STOP_INDEX-START_INDEX)*2);
	}
	
	private List<Integer> getDefaultListX2()
	{
		return makeList(START_INDEX, (STOP_INDEX-START_INDEX)*2);
	}
	
	private List getUncomparableList()
	{
		List l = makeList(0, 100);
		l.add(new Object());
		l.add(new String());
		l.add(l);
		return l;
	}
	
	private List getUnparameterizedList()
	{
		return getDefaultList();
	}
	
	private Comparator getStringComparator()
	{
		return new Comparator(){
			public int compare(Object o1, Object o2)
			{
				return ((String)o1).compareTo((String)o2);
			}
		};
	}
	
	
	
	//////////////////////////////////////////
	///////////////// TESTS //////////////////
	//////////////////////////////////////////
	
	//Also note that this method checks if the list implements RandomAccess,
	//and if so this runs in O(logn) time, otherwise it runs in O(n) time.

	//invalid key
	public void testBinarySearchException1()
	{
		this.expectException(new ClassCastException());
		MyCollections.binarySearch(getUnparameterizedList(), "yeah right", null);
	}
	
	public void testBinarySearch1()
	{
		List<Integer> l = getDefaultList();
		for (int i = 0; i < l.size(); i++)
			assert(MyCollections.binarySearch(l, i, null) == i);
	}
	
	public void testDisjoint1()
	{
		List<Integer> l1 = getDefaultList();
		List<Integer> l2 = this.getDefault2ndList();
		
		assert(MyCollections.disjoint(l1, l2));
		
		assert(!MyCollections.disjoint(l1, l1));
		
		assert(!MyCollections.disjoint(l2, this.getDefaultListX2()));
	}
	
	public void testDisjointException()
	{
		this.expectException(new NullPointerException());
		MyCollections.disjoint(null, new ArrayList());
	}
	
	public void testIndexOfSubList1()
	{
		
		assert(MyCollections.indexOfSubList(getDefault2ndList(), getDefaultList()) == -1);
		//assert(false);
	}
	
	public void testReverse1()
	{
		List l1 = getDefaultList();
		List l2 = getDefaultList();
		
		assert(l1.equals(l2));
		MyCollections.reverse(l1);
		MyCollections.reverse(l2);
		assert(l1.equals(l2)); // check if this actually works
	}
	

	
	public void testShuffle1()
	{
		List<Integer> l1 = getDefaultList();
		List<Integer> l2 = new ArrayList<Integer>(l1);
		
		assert(l1.equals(l2));
		
		MyCollections.shuffle(l1);
		
		assert(!l2.equals(l1));
		l2 = new ArrayList<Integer>(l1);
		
		MyCollections.shuffle(l1);
		assert(!l2.equals(l1));
	}
	


}
